@@ -1,5 +1,6 @@
 # Ignored NSE variables in devtools::check
 utils::globalVariables("time")
+utils::globalVariables("n")
 utils::globalVariables("n.event")
 utils::globalVariables("x")
 utils::globalVariables("y")
@@ -21,6 +22,8 @@ utils::globalVariables("treatments")
 utils::globalVariables("fixed_followup_days")
 utils::globalVariables("average")
 utils::globalVariables("value")
+utils::globalVariables("percentage")
+utils::globalVariables("name")
 utils::globalVariables(".env")
 utils::globalVariables("separation")
 utils::globalVariables("gap")
@@ -35,3 +38,12 @@ utils::globalVariables("xupper")
 utils::globalVariables("xmax")
 utils::globalVariables("xmax_final")
 utils::globalVariables("outliers")
+utils::globalVariables("GROUP")
+utils::globalVariables("TRTP")
+utils::globalVariables("WIN")
+utils::globalVariables("LOSS")
+utils::globalVariables("TIE")
+utils::globalVariables("TOTAL")
+utils::globalVariables("WIN_A")
+utils::globalVariables("WIN_P")
+utils::globalVariables("TIE_A")
