@@ -41,21 +41,21 @@
 #' )
 #' @export
 maraca <- function(
-    data,
-    tte_outcomes,
-    continuous_outcome,
-    arm_levels = c(
-      active = "active",
-      control = "control"
-    ),
-    column_names = c(
-      outcome = "outcome",
-      arm = "arm",
-      value = "value"
-    ),
-    fixed_followup_days,
-    compute_win_odds = FALSE
-    ) {
+  data,
+  tte_outcomes,
+  continuous_outcome,
+  arm_levels = c(
+    active = "active",
+    control = "control"
+  ),
+  column_names = c(
+    outcome = "outcome",
+    arm = "arm",
+    value = "value"
+  ),
+  fixed_followup_days,
+  compute_win_odds = FALSE
+) {
 
   checkmate::assert_data_frame(data)
   checkmate::assert_character(tte_outcomes, any.missing = FALSE)
@@ -63,27 +63,32 @@ maraca <- function(
   checkmate::assert_character(arm_levels, len = 2, any.missing = FALSE)
   checkmate::assert_names(
     names(arm_levels),
-    identical.to = c("active", "control")
+    permutation.of = c("active", "control")
   )
   checkmate::assert_character(column_names, len = 3, any.missing = FALSE)
   checkmate::assert_names(
     names(column_names),
-    identical.to = c("outcome", "arm", "value")
+    permutation.of = c("outcome", "arm", "value")
   )
+
   checkmate::assert_int(fixed_followup_days)
   checkmate::assert_flag(compute_win_odds)
 
   `%>%` <- dplyr::`%>%`
 
+  # Make sure that data is a data.frame
+  data <- as.data.frame(data, stringsAsFactors = FALSE)
+
   # Remove unwanted outcomes and arm levels, and normalise column names
   # in the internal data.
   # Note: We use HCE to refer to our internal, normalised data frame.
   # and with "data" to the user-provided, external, dirty data frame.
-  HCE <- .reformat_and_check_data(
-    data, tte_outcomes, continuous_outcome, arm_levels, column_names)
+  hce_dat <- .reformat_and_check_data(data, tte_outcomes,
+                                      continuous_outcome,
+                                      arm_levels, column_names)
 
   # Calculate meta information from the entire HCE dataset needed for plotting
-  meta <- .compute_metainfo(HCE)
+  meta <- .compute_metainfo(hce_dat)
 
   # In the current implementation of the package,
   # the fixed follow-up days given cannot be smaller
@@ -97,7 +102,7 @@ maraca <- function(
   # but will at the same time not include the MI since
   # we don't know about it
   if (fixed_followup_days <
-     max(meta[meta$outcome %in% tte_outcomes, "maxday"])) {
+        max(meta[meta$outcome %in% tte_outcomes, "maxday"])) {
     stop(paste("Time-to-event data contain events",
                "after the fixed_followup_days - either",
                "provide a longer follow-up time or",
@@ -109,21 +114,21 @@ maraca <- function(
   # automatically by survival package (should we done)
   # after the meta data is collected to keep information
   # on if missing data was removed
-  HCE <- HCE %>%
+  hce_dat <- hce_dat %>%
     dplyr::filter(!is.na(value))
 
   ecdf_by_outcome <- .compute_ecdf_by_outcome(
-    HCE, meta, tte_outcomes, continuous_outcome, arm_levels,
+    hce_dat, meta, tte_outcomes, continuous_outcome, arm_levels,
     fixed_followup_days
   )
 
   continuous <- .compute_continuous(
-    HCE, meta, ecdf_by_outcome, tte_outcomes, continuous_outcome, arm_levels
+    hce_dat, meta, ecdf_by_outcome, tte_outcomes, continuous_outcome, arm_levels
   )
 
-  win_odds <- NULL
+  win_odds <- list("win_odds" = NULL, "win_odds_outcome" = NULL)
   if (compute_win_odds) {
-    win_odds <- .compute_win_odds(HCE)
+    win_odds <- .compute_win_odds(hce_dat, arm_levels)
   }
 
   return(
@@ -137,7 +142,8 @@ maraca <- function(
         meta = meta,
         ecdf_by_outcome = ecdf_by_outcome,
         continuous = continuous,
-        win_odds = win_odds
+        win_odds = win_odds[["win_odds"]],
+        win_odds_outcome = win_odds[["win_odds_outcome"]]
       ),
       class = c("maraca")
     )
@@ -152,6 +158,8 @@ maraca <- function(
 #' @export
 print.maraca <- function(x, ...) {
 
+  `%>%` <- dplyr::`%>%`
+
   cat(paste("Maraca object for plotting maraca graph created for",
             sum(x$meta$n), "patients.\n\n"))
 
@@ -170,9 +178,11 @@ print.maraca <- function(x, ...) {
     cat("Win odds not calculated.\n\n")
   }
 
-  tmp <- as.data.frame(x$meta[, c("outcome", "n", "proportion",
-                                  "n_active", "n_control", "missing")])
-  names(tmp) <- toupper(names(tmp))
+  tmp <- x$meta %>%
+    dplyr::select(outcome, n, proportion,
+                  dplyr::starts_with("n_"), missing) %>%
+    as.data.frame()
+  names(tmp) <- .title_case(gsub("_", " ", names(tmp)))
   print(tmp, row.names = FALSE)
 
 }
@@ -189,6 +199,10 @@ print.maraca <- function(x, ...) {
 #'        part of the plot. Options are "default", "violin", "box", "scatter".
 #' @param vline_type what the vertical lines in the continuous part of the plot
 #'        should highlight. Options are "median", "mean", "none".
+#' @param theme Choose theme to style the plot. The default theme is "maraca".
+#'        Options are "maraca", "maraca_old", "color1", "color2" and none".
+#'        For more details, check the vignette called
+#'        "Maraca Plots - Themes and Styling".
 #' @return a ggplot2 object of the data. This function
 #' will not render the plot immediately. You have to print() the returned
 #' object for it to be displayed.
@@ -208,7 +222,8 @@ print.maraca <- function(x, ...) {
 plot_maraca <- function(
     obj, continuous_grid_spacing_x = 10, trans = "identity",
     density_plot_type = "default",
-    vline_type = "median") {
+    vline_type = "median",
+    theme = "maraca") {
   checkmate::assert_class(obj, "maraca")
   checkmate::assert_int(continuous_grid_spacing_x)
   checkmate::assert_string(trans)
@@ -225,11 +240,11 @@ plot_maraca <- function(
   continuous <- obj$continuous
   ecdf_mod <- obj$ecdf_by_outcome
   win_odds <- obj$win_odds
-  start_continuous_endpoint <- meta[
-    meta$outcome == obj$continuous_outcome, ]$startx
+  start_continuous_endpoint <-
+    meta[meta$outcome == obj$continuous_outcome, ]$startx
 
   plotdata_ecdf <- ecdf_mod$data[, c("outcome", "arm",
-                                    "adjusted.time", "ecdf_values")]
+                                     "adjusted.time", "ecdf_values")]
   plotdata_ecdf$type <- "tte"
   names(plotdata_ecdf) <- c("outcome", "arm", "x", "y", "type")
   plotdata_cont <- continuous$data[, c("outcome", "arm", "x", "y_level")]
@@ -285,7 +300,7 @@ plot_maraca <- function(
     ggplot2::geom_vline(
       xintercept = zeroposition,
       color = "white",
-      size = 1
+      linewidth = 1
     )
 
   if (vline_type == "median") {
@@ -297,7 +312,7 @@ plot_maraca <- function(
         ),
         data = continuous$meta,
         linetype = "dashed",
-        size = 0.8
+        linewidth = 0.8
       )
   } else if (vline_type == "mean") {
     plot <- plot +
@@ -308,30 +323,28 @@ plot_maraca <- function(
         ),
         data = continuous$meta,
         linetype = "dashed",
-        size = 0.8
+        linewidth = 0.8
       )
   }
 
   plot <- plot +
     ggplot2::geom_step(
-    data = plotdata[plotdata$type == "tte", ],
+      data = plotdata[plotdata$type == "tte", ],
       aes(x = x, y = y, color = arm)
     )
 
-  plot <- plot +
-    ggplot2::scale_color_discrete("Arm", labels = obj$arm_levels)
-
   if (density_plot_type == "default") {
     plot <- plot +
       ggplot2::geom_violin(
         data = plotdata[plotdata$type == "cont", ],
         aes(x = x, y = y, colour = arm, fill = arm), alpha = 0.5
       ) + ggplot2::geom_boxplot(
-        data = plotdata[plotdata$type == "cont", ],
-        aes(x = x, y = y, colour = arm, fill = arm), alpha = 0.5,
-        width = abs(diff(as.numeric(unique(
-          plotdata[plotdata$type == "cont", ]$y)))) / 3
-      )
+      data = plotdata[plotdata$type == "cont", ],
+      aes(x = x, y = y, colour = arm, fill = arm), alpha = 0.5,
+      width =
+        abs(diff(as.numeric(unique(plotdata[plotdata$type == "cont", ]$y)))) /
+        3
+    )
   } else if (density_plot_type == "violin") {
     plot <- plot +
       ggplot2::geom_violin(
@@ -362,8 +375,6 @@ plot_maraca <- function(
     }
   )
   plot <- plot +
-    ggplot2::xlab("Type of endpoint") +
-    ggplot2::ylab("Cumulative proportion") +
     ggplot2::scale_x_continuous(
       limits = c(0, 100),
       breaks = c(meta$proportion / 2 + meta$startx),
@@ -383,26 +394,16 @@ plot_maraca <- function(
         start_continuous_endpoint,
         min(continuous$data$value, na.rm = TRUE),
         max(continuous$data$value, na.rm = TRUE)
-        ),
+      ),
       y = 0,
       label = labels,
       color = "grey60"
     )
 
   if (!is.null(win_odds)) {
-    plot <- plot +
-    ggplot2::annotate(
-      geom = "label",
-      x = 0,
-      y = Inf,
-      label = paste(
-        "Win odds (95% CI): ", round(win_odds[[1]], 2),
-        " (", round(win_odds[[2]], 2), ", ", round(win_odds[[3]], 2), ")", "\n",
-        "p-value: ", format.pval(win_odds[[4]], digits = 3, eps = 0.001),
-        sep = ""
-      ),
-      hjust = 0, vjust = 1.4, size = 3
-    )
+
+    plot <- .add_win_odds_to_plot(plot, win_odds, 0, Inf,
+                                  hjust = 0)
 
     # Meta data on win odds will be added to plot
     win_odds <- unname(win_odds)
@@ -417,18 +418,19 @@ plot_maraca <- function(
     plot$labels$win.odds <- params
   }
 
+  plot <- switch(theme,
+                 "maraca" = .theme_maraca(plot),
+                 "maraca_old" = .theme_maraca_old(plot),
+                 "color1" = .theme_color1(plot),
+                 "color2" = .theme_color2(plot),
+                 "none" = plot,
+                 stop("Please provide theme that exists"))
+
   plot <- plot +
     ggplot2::theme(
-      axis.text.x.bottom = ggplot2::element_text(
-        angle = 90,
-        vjust = 0.5,
-        hjust = 1
-      ),
       axis.ticks.x.bottom = ggplot2::element_blank(),
-      panel.grid.major.x = ggplot2::element_blank(),
-      axis.title.x.bottom =  ggplot2::element_blank()
-    ) +
-    ggplot2::guides(fill = "none")
+      panel.grid.major.x = ggplot2::element_blank()
+    )
 
   # Add label to plot - maracaPlot
   class(plot) <- c("maracaPlot", class(plot))
@@ -472,8 +474,8 @@ validate_maraca_plot <- function(x,  ...) {
 
   arms <- levels(pb$plot$data[, pb$plot$labels$colour])
 
-  tte_data <- utils::tail(
-    utils::head(pb$data[[4]][, c("group", "x", "y")], -2), -2)
+  tte_data <-
+    utils::tail(utils::head(pb$data[[4]][, c("group", "x", "y")], -2), -2)
   tte_data$group <- factor(tte_data$group, labels = arms)
 
   scatter_data <- NULL
@@ -487,21 +489,22 @@ validate_maraca_plot <- function(x,  ...) {
     boxstat_data <- pb$data[[5]] %>%
       dplyr::select(group, "x_lowest" = xmin_final,
                     "whisker_lower" = xmin,
-             "hinge_lower" = xlower, "median" = xmiddle,
-             "hinge_upper" = xupper, "whisker_upper" = xmax,
-             "x_highest" = xmax_final, outliers)
+                    "hinge_lower" = xlower, "median" = xmiddle,
+                    "hinge_upper" = xupper, "whisker_upper" = xmax,
+                    "x_highest" = xmax_final, outliers)
     boxstat_data$outliers <- lapply(boxstat_data$outliers, sort)
     boxstat_data$group <- factor(boxstat_data$group, labels = arms)
   } else if (plot_type == "GeomViolin") {
     violin_data <- pb$data[[5]][, c("group", "x", "y", "density", "width")]
     violin_data$group <- factor(violin_data$group, labels = arms)
     if (class(as.list(x$layers[[6]])[["geom"]])[1] == "GeomBoxplot") {
+      plot_type <- paste(plot_type, "GeomBoxplot", sep = "+")
       boxstat_data <- pb$data[[6]] %>%
         dplyr::select(group, "x_lowest" = xmin_final,
                       "whisker_lower" = xmin,
-               "hinge_lower" = xlower, "median" = xmiddle,
-               "hinge_upper" = xupper, "whisker_upper" = xmax,
-               "x_highest" = xmax_final, outliers)
+                      "hinge_lower" = xlower, "median" = xmiddle,
+                      "hinge_upper" = xupper, "whisker_upper" = xmax,
+                      "x_highest" = xmax_final, outliers)
       boxstat_data$outliers <- lapply(boxstat_data$outliers, sort)
       boxstat_data$group <- factor(boxstat_data$group, labels = arms)
     }
@@ -544,7 +547,11 @@ validate_maraca_plot <- function(x,  ...) {
 #'        Accepts "default", "violin", "box" and "scatter".
 #' @param vline_type what the vertical dashed line should represent. Accepts
 #'        "median", "mean", "none".
-#' @return Used for side effect. Plots the maraca object.
+#' @param theme Choose theme to style the plot. The default theme is "maraca".
+#'        Options are "maraca", "maraca_old", "color1", "color2" and none".
+#'        For more details, check the vignette called
+#'        "Maraca Plots - Themes and Styling".
+#' @return Used for side effect. Returns ggplot2 plot of the maraca object.
 #'
 #' @examples
 #' data(hce_scenario_a)
@@ -564,9 +571,11 @@ plot.maraca <- function(
     x, continuous_grid_spacing_x = 10, trans = "identity",
     density_plot_type = "default",
     vline_type = "median",
+    theme = "maraca",
     ...) {
-  print(plot_maraca(
-    x, continuous_grid_spacing_x, trans, density_plot_type, vline_type))
+  plot_maraca(x, continuous_grid_spacing_x,
+              trans, density_plot_type,
+              vline_type, theme)
 }
 #' Generic function to plot the hce object using plot().
 #'
@@ -574,6 +583,12 @@ plot.maraca <- function(
 #' @param \dots not used
 #' @param continuous_outcome A single string containing the continuous
 #'                           outcome label. Default value "C".
+#' @param arm_levels A named vector of exactly two strings, mapping the
+#'                   values used for the active and control arms to the values
+#'                   used in the data. The names must be "active" and "control"
+#'                   in this order. Note that this parameter only need to
+#'                   be specified if you have labels different from
+#'                    "active" and "control".
 #' @param continuous_grid_spacing_x The spacing of the x grid to use for the
 #'        continuous section of the plot.
 #' @param trans the transformation to apply to the data before plotting.
@@ -584,328 +599,53 @@ plot.maraca <- function(
 #'        "median", "mean", "none".
 #' @param fixed_followup_days Not needed if HCE object contains information
 #'                            on fixed follow-up days in the study
-#'                            (column TTEfixed). Otherwise,
-#'                            this argument must be specified.
+#'                            (column PADY or TTEfixed,
+#'                            depending on hce version).
+#'                            Otherwise, this argument must be specified.
 #'                            Note: If argument is specified and HCE object
-#'                            contains TTEfixed column, then
+#'                            contains PADY or TTEfixed column, then
 #'                            fixed_followup_days argument is used.
 #' @param compute_win_odds If TRUE compute the win odds, otherwise (default)
 #'                         don't compute them.
-#' @return Used for side effect. Plots the maraca object.
+#' @param theme Choose theme to style the plot. The default theme is "maraca".
+#'        Options are "maraca", "maraca_old", "color1", "color2" and none".
+#'        For more details, check the vignette called
+#'        "Maraca Plots - Themes and Styling".
+#'        [companion vignette for package users](themes.html)
+#' @return Used for side effect. Returns ggplot2 plot of the hce object.
 #'
 #' @examples
-#' set.seed(31337)
 #' Rates_A <- c(1.72, 1.74, 0.58, 1.5, 1)
 #' Rates_P <- c(2.47, 2.24, 2.9, 4, 6)
-#' HCE <- hce::simHCE(n = 2500, TTE_A = Rates_A, TTE_P = Rates_P,
-#'              CM_A = -3, CM_P = -6, CSD_A = 16, CSD_P = 15, fixedfy = 3)
-#' plot(HCE)
-#' plot(HCE, fixed_followup_days = 3 * 365)
+#' hce_dat <- hce::simHCE(n = 2500, TTE_A = Rates_A, TTE_P = Rates_P,
+#'              CM_A = -3, CM_P = -6, CSD_A = 16, CSD_P = 15, fixedfy = 3,
+#'              seed = 31337)
+#' plot(hce_dat)
+#' plot(hce_dat, fixed_followup_days = 3 * 365)
 #'
 #' @export
 plot.hce <- function(x, continuous_outcome = "C",
+                     arm_levels = c(active = "A", control = "P"),
                      continuous_grid_spacing_x = 10,
                      trans = "identity",
                      density_plot_type = "default",
                      vline_type = "median",
                      fixed_followup_days = NULL,
-                     compute_win_odds = FALSE, ...) {
-  checkmate::assert_string(continuous_outcome)
+                     compute_win_odds = FALSE,
+                     theme = "maraca", ...) {
+
   checkmate::assert_int(continuous_grid_spacing_x)
   checkmate::assert_string(trans)
-  checkmate::assert_choice(
-    density_plot_type, c("default", "violin", "box", "scatter"))
+  checkmate::assert_choice(density_plot_type,
+                           c("default", "violin", "box", "scatter"))
   checkmate::assert_choice(
     vline_type, c("median", "mean", "none")
   )
-  checkmate::assert_flag(compute_win_odds)
-  checkmate::assertNames(names(x), must.include = "GROUP")
 
-  x <- as.data.frame(x)
-  TTE <- sort(unique(x$GROUP)[unique(x$GROUP) != continuous_outcome])
+  maraca_obj <- .maraca_from_hce_data(x, continuous_outcome, arm_levels,
+                                      fixed_followup_days,
+                                      compute_win_odds)
 
-  # Small bugfix to allow for name change of variable TTEFixed in newer
-  # version of HCE package
-  if ("PADY" %in% names(x)) {
-    x$TTEfixed <- x$PADY
-  }
-
-  if (is.null(fixed_followup_days)) {
-    checkmate::assertNames(names(x), must.include = "TTEfixed")
-    checkmate::assert_int(x$TTEfixed[[1]])
-    fixed_followup_days <- x$TTEfixed[[1]]
-  }
-
-  hce_test <- maraca(
-    data = x,
-    tte_outcomes = TTE,
-    continuous_outcome = continuous_outcome,
-    column_names = c(outcome = "GROUP", arm = "TRTP", value = "AVAL0"),
-    arm_levels = c(active = "A", control = "P"),
-    fixed_followup_days = fixed_followup_days,
-    compute_win_odds = compute_win_odds
-  )
-
-  print(plot_maraca(
-    hce_test, continuous_grid_spacing_x, trans, density_plot_type, vline_type))
-}
-
-### Private functions
-
-# Computes the win odds from the internal data.
-.compute_win_odds <- function(HCE) {
-  HCE <- base::as.data.frame(HCE)
-  HCE <- .with_ordered_column(HCE)
-  fit <- hce::calcWO(x = HCE, AVAL = "ordered", TRTP = "arm", ref = "control")
-  CI <- base::as.numeric(fit[, base::c("WO", "LCL", "UCL")])
-  p <- fit$Pvalue
-  win_odds <- base::c(CI, p)
-  names(win_odds) <- base::c("estimate", "lower", "upper", "p-value")
-  return(win_odds)
-}
-
-
-# This function does a bit of dirty magic to distribute the values
-# onto different "floors", each floor being a numeric offset that is higher
-# for each passing tte variable (and highest for the continuous).
-# In practice, we are translating the values for each tte variable group.
-# Explanation inline
-.with_ordered_column <- function(HCE) {
-  # We create a data frame, grouping according to the outcome,
-  # then we get the minimum and maximum values of the value.
-  # What we want to know is the "window" where data are for each of the groups
-  # We then select the largest window.
-  `%>%` <- dplyr::`%>%`
-
-  tmp <- HCE %>%
-    dplyr::group_by(outcome) %>%
-    dplyr::summarise(min = min(value), max = max(value)) %>%
-    dplyr::mutate(separation = max - min) %>%
-    dplyr::summarise(max_separation = max(separation))
-
-  # With the largest window found, we know that if we offset the data at
-  # least of this amount, they will never overlap. Bit of clever math here,
-  # we use a gap that is larger, amounting to the number of digits, so we
-  # have nicer gap value such as 10, 100, or 1000 etc.
-  gap <- 10 ^ ceiling(log10(tmp$max_separation)) # nolint
-
-  # apply the gap to all values. outcome is a factor, so we use its numeric
-  # value to multiply the offset, and end up having each value "translated up"
-  # of the proper amount.
-  HCE <- HCE %>%
-    dplyr::mutate(ordered = .env$gap * (as.numeric(outcome) - 1) + value)
-
-  # and now we have a new data set with the column added.
-  return(HCE)
-}
-
-# Computes the metainfo from the internal HCE data.
-.compute_metainfo <- function(HCE) {
-  n <- dplyr::n
-  `%>%` <- dplyr::`%>%`
-
-  meta1 <- HCE  %>%
-    dplyr::filter(!is.na(value)) %>%
-    dplyr::group_by(outcome) %>%
-    dplyr::summarise(
-      n = n(),
-      proportion = n / dim(HCE)[[1]] * 100,
-      maxday = max(value, na.rm = TRUE)
-    ) %>%
-    dplyr::mutate(
-      startx = c(0, cumsum(utils::head(proportion, -1))),
-      endx = cumsum(proportion),
-      starty = 0,
-      n.groups = length(unique(outcome))
-    )
-
-  meta2 <- HCE  %>%
-    dplyr::filter(!is.na(value)) %>%
-    dplyr::group_by(outcome, arm) %>%
-    dplyr::summarise(n = n(), proportion = n / dim(HCE)[[1]] * 100) %>%
-    tidyr::pivot_wider(names_from = arm, values_from = c(n, proportion))
-
-  meta_missing <- HCE %>%
-    dplyr::group_by(outcome) %>%
-    dplyr::summarise(
-      missing = sum(is.na(value))
-    )
-
-  meta <- dplyr::left_join(meta1, meta2, "outcome")
-  meta <- dplyr::left_join(meta, meta_missing, "outcome")
-
-  return(meta)
-}
-
-# Calculates the cumulative distribution for TTE outcomes
-.compute_ecdf_by_outcome <- function(
-  HCE, meta, tte_outcomes, continuous_outcome, arm_levels,
-  fixed_followup_days
-) {
-
-  `%>%` <- dplyr::`%>%`
-  n <- dplyr::n
-
-  num_tte_outcomes <- length(tte_outcomes)
-  HCE$t_cdf <- (num_tte_outcomes + 2) * fixed_followup_days
-
-  for (i in seq_len(num_tte_outcomes)) {
-    HCE[HCE$outcome == tte_outcomes[[i]], ]$t_cdf <-
-      HCE[HCE$outcome == tte_outcomes[[i]], ]$value +
-        fixed_followup_days * (i - 1)
-  }
-
-  HCE_ecdf <-
-    do.call("rbind",
-            lapply(unique(HCE$arm), function(a, df, outcomes) {
-      tmp <- df %>% dplyr::filter(arm == a)
-      tmp$ecdf_values <- 100 *
-        stats::ecdf(tmp$t_cdf)(tmp$t_cdf)
-      tmp %>% dplyr::filter(outcome %in% outcomes)
-  }, df = HCE, outcomes = tte_outcomes))
-
-  HCE_ecdf <- HCE_ecdf[order(HCE_ecdf$ecdf_values), ]
-
-  HCE_ecdf$adjusted.time <- 0
-  for (entry in tte_outcomes) {
-    outcome_filter <- HCE_ecdf$outcome == entry
-    HCE_ecdf[outcome_filter, ]$adjusted.time <-
-      meta[meta$outcome == entry, ]$startx +
-      HCE_ecdf[outcome_filter, ]$value /
-      fixed_followup_days *
-      meta[meta$outcome == entry, ]$proportion
-  }
-
-  HCE_ecdf_meta <- HCE_ecdf %>%
-    dplyr::group_by(arm, outcome) %>%
-    dplyr::summarise(
-      max = max(ecdf_values, na.rm = TRUE),
-      sum.event = n()) %>%
-    dplyr::mutate(
-      ecdf_end = utils::tail(max, 1)
-    )
-
-  return(list(
-    data = HCE_ecdf,
-    meta = HCE_ecdf_meta
-  ))
-}
-
-# Support function for the range
-.to_rangeab <- function(x, start_continuous_endpoint, minval, maxval) {
-  (100 - start_continuous_endpoint) * (x - minval) /
-  (maxval - minval) + start_continuous_endpoint
-}
-
-# Computes the continuous information
-.compute_continuous <- function(
-    HCE, meta, ecdf_mod, tte_outcomes, continuous_outcome, arm_levels) {
-  `%>%` <- dplyr::`%>%`
-  n <- dplyr::n
-
-  continuous_data <- HCE[HCE$outcome == continuous_outcome, ]
-  start_continuous_endpoint <- meta[meta$outcome == continuous_outcome, ]$startx
-
-  continuous_data$x <- .to_rangeab(
-    continuous_data$value,
-    start_continuous_endpoint,
-    min(continuous_data$value, na.rm = TRUE),
-    max(continuous_data$value, na.rm = TRUE)
-  )
-  continuous_meta <- continuous_data %>%
-    dplyr::group_by(arm) %>%
-    dplyr::summarise(n = n(), median = stats::median(x, na.rm = TRUE),
-      average = base::mean(x, na.rm = TRUE))
-
-  continuous_data$y_level <- ecdf_mod$meta[
-    ecdf_mod$meta$arm == "active" &
-    ecdf_mod$meta$outcome == utils::tail(tte_outcomes, 1),
-    ]$ecdf_end
-  continuous_data[continuous_data$arm == "control", ]$y_level <- ecdf_mod$meta[
-    ecdf_mod$meta$arm == "control" &
-    ecdf_mod$meta$outcome == utils::tail(tte_outcomes, 1),
-    ]$ecdf_end
-
-  return(list(
-    data = continuous_data,
-    meta = continuous_meta
-  ))
-}
-
-# Reformats the data coming in from outside so that it fits our expectation.
-.reformat_and_check_data <- function(
-    data, tte_outcomes, continuous_outcome, arm_levels, column_names) {
-  `%>%` <- dplyr::`%>%`
-  vars <- dplyr::vars
-  all_of <- dplyr::all_of
-
-  HCE <- data %>%
-    dplyr::rename(all_of(column_names)) %>%
-    dplyr::select(all_of(names(column_names)))
-
-  # Check if the arm and outcome are strings, rather than factors.
-  if (!inherits(HCE[, "arm"], "character")) {
-    stop(paste(
-      "The arm column must be characters.",
-      "If you used read.csv, ensure you specify stringsAsFactors = FALSE."
-    ))
-  }
-
-  if (!inherits(HCE[, "outcome"], "character")) {
-    stop(paste(
-      "The outcome column must be characters.",
-      "If you used read.csv, ensure you specify stringsAsFactors = FALSE."
-    ))
-  }
-
-  inverse_map <- stats::setNames(names(arm_levels), arm_levels)
-  HCE$arm <- sapply(HCE$arm, function(x) {
-    return(inverse_map[x])
-  })
-
-  endpoints <- c(tte_outcomes, continuous_outcome)
-  HCE <- HCE %>%
-    dplyr::filter(outcome %in% endpoints) %>%
-    dplyr::mutate_at(vars(outcome), factor, levels = endpoints) %>%
-    dplyr::mutate_at(vars(arm), factor, levels = names(arm_levels))
-
-  # Check if the endpoints are all present
-  for (entry in c(tte_outcomes, continuous_outcome)) {
-    if (!any(HCE$outcome == entry)) {
-      stop(paste(
-        "Outcome", entry, "is not present in column",
-        column_names[["outcome"]]
-      ))
-    }
-  }
-
-  return(HCE)
-
-}
-
-.minor_grid <- function(values, scale, continuous_grid_spacing_x) {
-  minval <- min(values, na.rm = TRUE)
-  maxval <- max(values, na.rm = TRUE)
-
-  minor_grid_left <- c(0)
-  if ((10^scale) * floor(minval * 10^(-scale)) < 0) {
-    minor_grid_left <- rev(seq(
-      0,
-      (10^scale) * floor(minval * 10^(-scale)),
-      by = -continuous_grid_spacing_x
-    ))
-  }
-
-  minor_grid_right <- c(0)
-  if ((10^scale) * ceiling(maxval * 10^(-scale)) > 0) {
-    minor_grid_right <- seq(
-      0,
-      (10^scale) * ceiling(maxval * 10^(-scale)),
-      by = continuous_grid_spacing_x
-    )
-  }
-  minor_grid <- unique(c(minor_grid_left, minor_grid_right))
-  minor_grid <- minor_grid[minor_grid >= minval & minor_grid <= maxval]
-
-  return(minor_grid)
+  plot_maraca(maraca_obj, continuous_grid_spacing_x,
+              trans, density_plot_type, vline_type, theme)
 }
